
# Topic 101: System Architecture

## 101.1 Determine and configure hardware settings

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/101/101.1/101.1_01/)

**Weight:** 2

Description: Candidates should be able to determine and configure fundamental system hardware

Key Knowledge Areas:

Enable and disable integrated peripherals.
Differentiate between the various types of mass storage devices.
Determine hardware resources for devices.
Tools and utilities to list various hardware information (e.g. lsusb, lspci, etc.).
Tools and utilities to manipulate USB devices.
Conceptual understanding of sysfs, udev and dbus.
The following is a partial list of the used files, terms and utilities:

```bash
/sys/
/proc/
/dev/
modprobe
lsmod
lspci
lsusb
```

## 101.2 Boot the system

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/101/101.2/101.2_01/)

**Weight:** 3

Description: Candidates should be able to guide the system through the booting process.

Key Knowledge Areas:

Provide common commands to the boot loader and options to the kernel at boot time.
Demonstrate knowledge of the boot sequence from BIOS/UEFI to boot completion.
Understanding of SysVinit and systemd.
Awareness of Upstart.
Check boot events in the log files.
The following is a partial list of the used files, terms and utilities:

```bash
dmesg
journalctl
BIOS
UEFI
bootloader
kernel
initramfs
init
SysVinit
systemd
```

## 101.3 Change runlevels / boot targets and shutdown or reboot system

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/101/101.3/101.3_01/)

**Weight:** 3

Description: Candidates should be able to manage the SysVinit runlevel or systemd boot target of the system. This objective includes changing to single user mode, shutdown or rebooting the system. Candidates should be able to alert users before switching runlevels / boot targets and properly terminate processes. This objective also includes setting the default SysVinit runlevel or systemd boot target. It also includes awareness of Upstart as an alternative to SysVinit or systemd.

Key Knowledge Areas:

Set the default runlevel or boot target.
Change between runlevels / boot targets including single user mode.
Shutdown and reboot from the command line.
Alert users before switching runlevels / boot targets or other major system events.
Properly terminate processes.
Awareness of acpid.
The following is a partial list of the used files, terms and utilities:

```bash
/etc/inittab
shutdown
init
/etc/init.d/
telinit
systemd
systemctl
/etc/systemd/
/usr/lib/systemd/
wall
```

# Topic 102: Linux Installation and Package Management

## 102.1 Design hard disk layout

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/102/102.1/102.1_01/)

**Weight:** 2

Description: Candidates should be able to design a disk partitioning scheme for a Linux system.

Key Knowledge Areas:

Allocate filesystems and swap space to separate partitions or disks.
Tailor the design to the intended use of the system.
Ensure the /boot partition conforms to the hardware architecture requirements for booting.
Knowledge of basic features of LVM.
The following is a partial list of the used files, terms and utilities:

```bash
/ (root) filesystem
/var filesystem
/home filesystem
/boot filesystem
EFI System Partition (ESP)
swap space
mount points
partitions
```
 
## 102.2 Install a boot manager

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/102/102.2/102.2_01/)

**Weight:** 2

Description: Candidates should be able to select, install and configure a boot manager.

Key Knowledge Areas:

Providing alternative boot locations and backup boot options.
Install and configure a boot loader such as GRUB Legacy.
Perform basic configuration changes for GRUB 2.
Interact with the boot loader.
The following is a partial list of the used files, terms and utilities:

```bash
menu.lst, grub.cfg and grub.conf
grub-install
grub-mkconfig
MBR
```

## 102.3 Manage shared libraries

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/102/102.3/102.3_01/)

**Weight:** 1

Description: Candidates should be able to determine the shared libraries that executable programs depend on and install them when necessary.

Key Knowledge Areas:

Identify shared libraries.
Identify the typical locations of system libraries.
Load shared libraries.
The following is a partial list of the used files, terms and utilities:

```bash
ldd
ldconfig
/etc/ld.so.conf
LD_LIBRARY_PATH
```

## 102.4 Use Debian package management

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/102/102.4/102.4_01/)

**Weight:** 3

Description: Candidates should be able to perform package management using the Debian package tools.

Key Knowledge Areas:

Install, upgrade and uninstall Debian binary packages.
Find packages containing specific files or libraries which may or may not be installed.
Obtain package information like version, content, dependencies, package integrity and installation status (whether or not the package is installed).
Awareness of apt.
The following is a partial list of the used files, terms and utilities:

```bash
/etc/apt/sources.list
dpkg
dpkg-reconfigure
apt-get
apt-cache
```

## 102.5 Use RPM and YUM package management

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/102/102.5/102.5_01/)

Weight：  3

Description: Candidates should be able to perform package management using RPM, YUM and Zypper.

Key Knowledge Areas:

Install, re-install, upgrade and remove packages using RPM, YUM and Zypper.
Obtain information on RPM packages such as version, status, dependencies, integrity and signatures.
Determine what files a package provides, as well as find which package a specific file comes from.
Awareness of dnf.
The following is a partial list of the used files, terms and utilities:

```bash
rpm
rpm2cpio
/etc/yum.conf
/etc/yum.repos.d/
yum
zypper
```
 
## 102.6 Linux as a virtualization guest

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/102/102.6/102.6_01/)

**Weight:** 1

Description: Candidates should understand the implications of virtualization and cloud computing on a Linux guest system.

Key Knowledge Areas:

Understand the general concept of virtual machines and containers.
Understand common elements virtual machines in an IaaS cloud, such as computing instances, block storage and networking.
Understand unique properties of a Linux system which have to changed when a system is cloned or used as a template.
Understand how system images are used to deploy virtual machines, cloud instances and containers.
Understand Linux extensions which integrate Linux with a virtualization product.
Awareness of cloud-init.
The following is a partial list of the used files, terms and utilities:

Virtual machine
Linux container
Application container
Guest drivers
SSH host keys
D-Bus machine id

# Topic 103: GNU and Unix Commands

## 103.1 Work on the command line

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.1/103.1_01/)
* [LPI Lesson 2](https://learning.lpi.org/en/learning-materials/101-500/103/103.1/103.1_02/)

**Weight:** 4

Description: Candidates should be able to interact with shells and commands using the command line. The objective assumes the Bash shell.

Key Knowledge Areas:

Use single shell commands and one line command sequences to perform basic tasks on the command line.
Use and modify the shell environment including defining, referencing and exporting environment variables.
Use and edit command history.
Invoke commands inside and outside the defined path.
The following is a partial list of the used files, terms and utilities:

```bash
bash
echo
env
export
pwd
set
unset
type
which
man
uname
history
.bash_history
Quoting
```

## 103.2 Process text streams using filters

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.2/103.2_01/)

**Weight:** 2

Description: Candidates should be able to apply filters to text streams.

Key Knowledge Areas:

Send text files and output streams through text utility filters to modify the output using standard UNIX commands found in the GNU textutils package.
The following is a partial list of the used files, terms and utilities:

```bash
bzcat
cat
cut
head
less
md5sum
nl
od
paste
sed
sha256sum
sha512sum
sort
split
tail
tr
uniq
wc
xzcat
zcat
```

## 103.3 Perform basic file management

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.3/103.3_01/)
* [LPI Lesson 2](https://learning.lpi.org/en/learning-materials/101-500/103/103.3/103.3_02/)

**Weight:** 4

Description: Candidates should be able to use the basic Linux commands to manage files and directories.

Key Knowledge Areas:

Copy, move and remove files and directories individually.
Copy multiple files and directories recursively.
Remove files and directories recursively.
Use simple and advanced wildcard specifications in commands.
Using find to locate and act on files based on type, size, or time.
Usage of tar, cpio and dd.
The following is a partial list of the used files, terms and utilities:

```bash
cp
find
mkdir
mv
ls
rm
rmdir
touch
tar
cpio
dd
file
gzip
gunzip
bzip2
bunzip2
xz
unxz
file globbing
```

## 103.4 Use streams, pipes and redirects

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.4/103.4_01/)
* [LPI Lesson 2](https://learning.lpi.org/en/learning-materials/101-500/103/103.4/103.4_02/)

**Weight:** 4

Description: Candidates should be able to redirect streams and connect them in order to efficiently process textual data. Tasks include redirecting standard input, standard output and standard error, piping the output of one command to the input of another command, using the output of one command as arguments to another command and sending output to both stdout and a file.

Key Knowledge Areas:

Redirecting standard input, standard output and standard error.
Pipe the output of one command to the input of another command.
Use the output of one command as arguments to another command.
Send output to both stdout and a file.
The following is a partial list of the used files, terms and utilities:

```bash
tee
xargs
```

## 103.5 Create, monitor and kill processes

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.5/103.5_01/)
* [LPI Lesson 2](https://learning.lpi.org/en/learning-materials/101-500/103/103.5/103.5_02/)

**Weight:** 4

Description: Candidates should be able to perform basic process management.

Key Knowledge Areas:

Run jobs in the foreground and background.
Signal a program to continue running after logout.
Monitor active processes.
Select and sort processes for display.
Send signals to processes.
The following is a partial list of the used files, terms and utilities:

```bash
&
bg
fg
jobs
kill
nohup
ps
top
free
uptime
pgrep
pkill
killall
watch
screen
tmux
```

## 103.6 Modify process execution priorities

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.6/103.6_01/)

**Weight:** 2

Description: Candidates should should be able to manage process execution priorities.

Key Knowledge Areas:

Know the default priority of a job that is created.
Run a program with higher or lower priority than the default.
Change the priority of a running process.
The following is a partial list of the used files, terms and utilities:

```bash
nice
ps
renice
top
```

## 103.7 Search text files using regular expressions

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.7/103.7_01/)
* [LPI Lesson 2](https://learning.lpi.org/en/learning-materials/101-500/103/103.7/103.7_02/)

**Weight:** 3

Description: Candidates should be able to manipulate files and text data using regular expressions. This objective includes creating simple regular expressions containing several notational elements as well as understanding the differences between basic and extended regular expressions. It also includes using regular expression tools to perform searches through a filesystem or file content.

Key Knowledge Areas:

Create simple regular expressions containing several notational elements.
Understand the differences between basic and extended regular expressions.
Understand the concepts of special characters, character classes, quantifiers and anchors.
Use regular expression tools to perform searches through a filesystem or file content.
Use regular expressions to delete, change and substitute text.
The following is a partial list of the used files, terms and utilities:

```bash
grep
egrep
fgrep
sed
regex(7)
```

## 103.8 Basic file editing

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/103/103.8/103.8_01/)

**Weight:** 3

Description: Candidates should be able to edit text files using vi. This objective includes vi navigation, vi modes, inserting, editing, deleting, copying and finding text. It also includes awareness of other common editors and setting the default editor.

Key Knowledge Areas:

Navigate a document using vi.
Understand and use vi modes.
Insert, edit, delete, copy and find text in vi.
Awareness of Emacs, nano and vim.
Configure the standard editor.
Terms and Utilities:

```bash
vi
/, ?
h,j,k,l
i, o, a
d, p, y, dd, yy
ZZ, :w!, :q!
EDITOR
```

# Topic 104: Devices, Linux Filesystems, Filesystem Hierarchy Standard

## 104.1 Create partitions and filesystems

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/104/104.1/104.1_01/)

**Weight:** 2

Description: Candidates should be able to configure disk partitions and then create filesystems on media such as hard disks. This includes the handling of swap partitions.

Key Knowledge Areas:

Manage MBR and GPT partition tables
Use various mkfs commands to create various filesystems such as:
ext2/ext3/ext4
XFS
VFAT
exFAT

Basic feature knowledge of Btrfs, including multi-device filesystems, compression and subvolumes.
The following is a partial list of the used files, terms and utilities:

```bash
fdisk
gdisk
parted
mkfs
mkswap
```

## 104.2 Maintain the integrity of filesystems

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/104/104.2/104.2_01/)

**Weight:** 2

Description: Candidates should be able to maintain a standard filesystem, as well as the extra data associated with a journaling filesystem.

Key Knowledge Areas:

Verify the integrity of filesystems.
Monitor free space and inodes.
Repair simple filesystem problems.
The following is a partial list of the used files, terms and utilities:

```bash
du
df
fsck
e2fsck
mke2fs
tune2fs
xfs_repair
xfs_fsr
xfs_db
```

## 104.3 Control mounting and unmounting of filesystems

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/104/104.3/104.3_01/)

**Weight:** 3

Description: Candidates should be able to configure the mounting of a filesystem.

Key Knowledge Areas:

Manually mount and unmount filesystems.
Configure filesystem mounting on bootup.
Configure user mountable removable filesystems.
Use of labels and UUIDs for identifying and mounting file systems.
Awareness of systemd mount units.
The following is a partial list of the used files, terms and utilities:

```bash
/etc/fstab
/media/
mount
umount
blkid
lsblk
```

## 104.4 Removed

## 104.5 Manage file permissions and ownership

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/104/104.5/104.5_01/)

**Weight:** 3

Description: Candidates should be able to control file access through the proper use of permissions and ownerships.

Key Knowledge Areas:

Manage access permissions on regular and special files as well as directories.
Use access modes such as suid, sgid and the sticky bit to maintain security.
Know how to change the file creation mask.
Use the group field to grant file access to group members.
The following is a partial list of the used files, terms and utilities:

```bash
chmod
umask
chown
chgrp
```

## 104.6 Create and change hard and symbolic links

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/104/104.6/104.6_01/)

**Weight:** 2

Description: Candidates should be able to create and manage hard and symbolic links to a file.

Key Knowledge Areas:

Create links.
Identify hard and/or soft links.
Copying versus linking files.
Use links to support system administration tasks.
The following is a partial list of the used files, terms and utilities:

```bash
ln
ls
```

## 104.7 Find system files and place files in the correct location

* [LPI Lesson 1](https://learning.lpi.org/en/learning-materials/101-500/104/104.7/104.7_01/)

**Weight:** 2

Description: Candidates should be thoroughly familiar with the Filesystem Hierarchy Standard (FHS), including typical file locations and directory classifications.

Key Knowledge Areas:

Understand the correct locations of files under the FHS.
Find files and commands on a Linux system.
Know the location and purpose of important file and directories as defined in the FHS.
The following is a partial list of the used files, terms and utilities:

```bash
find
locate
updatedb
whereis
which
type
/etc/updatedb.conf
```
